@@ -1235,8 +1235,7 @@ class Graphs(object):
         Expects user_id to be a comma-separated list of ints.
         """
         user_cond = ''
-
-        if session.get_session_user_id() and user_id and user_id != str(session.get_session_user_id()):
+        if session.get_session_user_id():
             user_cond = cond_prefix + ' session_history.user_id = %s ' % session.get_session_user_id()
         elif user_id:
             user_ids = helpers.split_strip(user_id)
